==> haskell-pcg-random-0.1.4.0-25-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pcg-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pcg-random
version:              0.1.4.0
visibility:           public
id:                   pcg-random-0.1.4.0-EkihgUZgdosBJNT80zujua
key:                  pcg-random-0.1.4.0-EkihgUZgdosBJNT80zujua
license:              BSD-3-Clause
copyright:            (c) 2014-2015. Christopher Chalmers <c.chalmers@me.com>
maintainer:           c.chalmers@me.com
author:               Christopher Chalmers
homepage:             http://github.com/cchalmers/pcg-random
synopsis:             Haskell bindings to the PCG random number generator.
description:
    PCG is a family of simple fast space-efficient statistically good
    algorithms for random number generation. Unlike many general-purpose
    RNGs, they are also hard to predict.

    This library implements bindings to the standard C implementation.
    This includes the standard, unique, fast and single variants in the
    pcg family. There is a pure implementation that can be used as a
    generator with the random package as well as a faster primitive api
    that includes functions for generating common types.

    The generators in this module are suitable for use in parallel but
    make sure threads don'\''t share the same generator or things will go
    horribly wrong.

category:             System
abi:                  1dbe1a0908e1adff66b0122560571625
exposed:              True
exposed-modules:
    System.Random.PCG System.Random.PCG.Class System.Random.PCG.Fast
    System.Random.PCG.Fast.Pure System.Random.PCG.Pure
    System.Random.PCG.Single System.Random.PCG.Unique

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pcg-random-0.1.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pcg-random-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcg-random
hs-libraries:         HSpcg-random-0.1.4.0-EkihgUZgdosBJNT80zujua
include-dirs:         /usr/lib/ghc-9.2.8/site-local/pcg-random-0.1.4.0/include
includes:             pcg_variants.h
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    entropy-0.4.1.10-C5y4ZMubclPFkOssafbGqV
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh

haddock-interfaces:   /usr/share/doc/haskell-pcg-random/html/pcg-random.haddock
haddock-html:         /usr/share/doc/haskell-pcg-random/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcg-random-0.1.4.0-55.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pcg-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pcg-random
version:              0.1.4.0
visibility:           public
id:                   pcg-random-0.1.4.0-8lZgYYihHq2BuK7Gc8yPgZ
key:                  pcg-random-0.1.4.0-8lZgYYihHq2BuK7Gc8yPgZ
license:              BSD-3-Clause
copyright:            (c) 2014-2015. Christopher Chalmers <c.chalmers@me.com>
maintainer:           c.chalmers@me.com
author:               Christopher Chalmers
homepage:             http://github.com/cchalmers/pcg-random
synopsis:             Haskell bindings to the PCG random number generator.
description:
    PCG is a family of simple fast space-efficient statistically good
    algorithms for random number generation. Unlike many general-purpose
    RNGs, they are also hard to predict.

    This library implements bindings to the standard C implementation.
    This includes the standard, unique, fast and single variants in the
    pcg family. There is a pure implementation that can be used as a
    generator with the random package as well as a faster primitive api
    that includes functions for generating common types.

    The generators in this module are suitable for use in parallel but
    make sure threads don'\''t share the same generator or things will go
    horribly wrong.

category:             System
abi:                  4d39e25aafb7ae3ae78425970b082161
exposed:              True
exposed-modules:
    System.Random.PCG System.Random.PCG.Class System.Random.PCG.Fast
    System.Random.PCG.Fast.Pure System.Random.PCG.Pure
    System.Random.PCG.Single System.Random.PCG.Unique

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pcg-random-0.1.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pcg-random-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pcg-random-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pcg-random
hs-libraries:         HSpcg-random-0.1.4.0-8lZgYYihHq2BuK7Gc8yPgZ
include-dirs:         /usr/lib/ghc-9.4.8/site-local/pcg-random-0.1.4.0/include
includes:             pcg_variants.h
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    primitive-0.8.0.0-RoAiLvCruBL00EsvIFp5f
    random-1.2.1.2-5Y3bNr2vhgE1UbXPPVLWyj

haddock-interfaces:   /usr/share/doc/haskell-pcg-random/html/pcg-random.haddock
haddock-html:         /usr/share/doc/haskell-pcg-random/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
